# praat_procedures.praat
#
# djmw 20040303 Default font is Times 10
# djmw 20040322 Added logfile_... 

# if undefined(savedir$) generate error message. 

length_savedir = length(savedir$)

vp_debug = 0
  
procedure save file$
	filepath$ = "'savedir$'"+"'file$'"
	Select outer viewport... 0 vp_x2 0 vp_y2
	Write to EPS file... 'filepath$'.eps
	system epstopdf --outfile='filepath$'.pdf 'filepath$'.eps
endproc

procedure vp_margins ml mr mt mb
  vp_ml = ml / 2.54
  vp_mr = mr / 2.54
  vp_mt = mt / 2.54
  vp_mb = mb / 2.54
endproc

# example: call vp_init 12 12 2 3 1 
#  1 2
#  3 4
#  5 6
# Usage:
# call vp_init  12 12 2 3 1
# call vp_set_vp
# Draw...
# call vp_set_vp
# Draw...
# call vp_set_vp
# Draw...
# etc...
#
# vp_lx and vp_ly in cm
procedure vp_init_base vp_lx vp_ly vp_nx vp_ny vp_sequence newpage
    if newpage <> 0
		Erase all
		vp_x1 = 0
		vp_y1 = 0
		vp_x2 = 0
		vp_y2 = 0
	endif
	if vp_sequence = 1
		vp_x1 = 0
		vp_y1 = vp_y2
	else
		vp_y1 = 0
		vp_x1 = vp_x2
	endif			
	vp_dx = vp_lx / 2.54 / vp_nx
	vp_dy = vp_ly / 2.54 / vp_ny
	vp_index = 0
	Times
	Font size... 10
	Black
	Plain line
endproc

procedure vp_init vp_lx vp_ly vp_nx vp_ny vp_sequence
	call vp_margins 0 0 0 0
	call vp_init_base vp_lx vp_ly vp_nx vp_ny vp_sequence 1
endproc

# if you draw LR then new vp at bottom
# if you draw TB then new vp ar right
procedure vp_initr vp_lx vp_ly vp_nx vp_ny vp_sequencer
	vp_sequence_pre = vp_sequence
	call vp_init_base vp_lx vp_ly vp_nx vp_ny vp_sequencer 0
    if vp_sequence_pre = 1
		vp_x1 = 0
		vp_y1 = vp_y2
	else 
		vp_x1 = vp_x2
		vp_y1 = 0
	endif
endproc

procedure vp_next
	if vp_index < vp_nx * vp_ny
		if vp_index = 0
			vp_x2 = vp_x1 + vp_dx
			vp_y2 = vp_y1 + vp_dy
		else
			if vp_sequence = 1
				# right-left
				if (vp_index mod vp_nx) = 0
					vp_y1 = vp_y2
					vp_y2 = vp_y1 + vp_dy
					vp_x1 = 0
				else
					vp_x1 = vp_x2
				endif
				vp_x2 = vp_x1 + vp_dx
			else
				# top-bottom
				if (vp_index mod vp_ny) = 0
					vp_x1 = vp_x2
					vp_x2 = vp_x1 + vp_dx
					vp_y1 = 0
				else
					vp_y1 = vp_y2		
				endif
				vp_y2 = vp_y1 + vp_dy
			endif
		endif
		if vp_debug <> 0
			printline vp_next: vp_index = 'vp_index' vp_sequence ='vp_sequence'
			printline vp_next: viewport 'vp_x1' 'vp_x2' 'vp_y1' 'vp_y2' 
		endif
		Select outer viewport... vp_x1-vp_ml vp_x2+vp_mr vp_y1-vp_mt vp_y2+vp_mb
		vp_index += 1
	endif
endproc

procedure logfile_open name$
  datef$ = savedir$+ "date"
  system  date +%F > 'datef$'
  daten$ < 'datef$'
  ! remove newline
  slen = length (daten$)
  logfile_date$ = left$ (daten$, slen-1)
  logfile$   = savedir$ + name$ + "-" + logfile_date$ + ".log"
  logfiletext$ = date$()
  filedelete 'logfile$'
  fileappend 'logfile$' 'logfiletext$''newline$'
endproc

procedure logfile_append logfiletext$
  fileappend 'logfile$' 'logfiletext$''newline$'
endproc
  
procedure logfile_close
  logfiletext$ = date$ ()
  fileappend 'logfile$' 'logfiletext$''newline$'
endproc

procedure latex_table table$ precision
  select TableOfReal 'table$'
  nr = Get number of rows
  nc = Get number of columns
  str$ = " & "
  post$ = " & "
  for i to nc
    if i = nc
      post$ = "\\"
    endif
    label$ = Get column label... i
    str$ = "'str$'" + "'label$'"+"'post$'" 
  endfor
  printline 'str$'
  for i to nr
    label$ = Get row label... i
    post$ = " & "
    str$ = "'label$'" + "'post$'"
    for j to nc
      d = TableOfReal_'table$'[i,j]
      pre$ = ""
      if d < 0
        pre$ = "$-$"
        d = abs (d)
      endif
      d$ = fixed$ (d, precision)
      if j = nc
        post$ = "\\"
      endif
      str$ = "'str$'" + "'pre$'" + "'d$'" + "'post$'"
    endfor
    printline 'str$'
  endfor
endproc
